@@ -223,7 +223,7 @@ class Objeto():
     #nome da imagem
     @property
     def nome_da_imagem(self):
-        return _nome_da_imagem
+        return self._nome_da_imagem
 
     @nome_da_imagem.setter
     def nome_da_imagem(self, nome_da_imagem ):
@@ -268,7 +268,7 @@ class Objeto():
 
     #Função que move o objeto criado na tela    
     def mover(self):
-        global rodar_threading
+        global rodar_threading, tela
         while rodar_threading and self._existe:
             if(self.velocidade <= 0):
                 pygame.time.Clock().tick(10)
@@ -276,7 +276,7 @@ class Objeto():
             #Velocidade é usada como clock para que o objeto se mova
             #em 1px a cada 1/velocidade segundos
             pygame.time.Clock().tick(self.velocidade)
-            
+
             #não mover se o objeto estiver
             #estático
             if( self.estatico ):
@@ -542,6 +542,7 @@ class Objeto():
     #em paralelo
     def adicionar_movimento(self, movimento ):
         def movimento_em_loop(): #tentar futuramente incluir numa lista
+            global tela
             while rodar_threading and self._existe:
                 pygame.time.Clock().tick( self.velocidade )
                 movimento( self )
@@ -559,10 +560,10 @@ class Objeto():
 
     #testa se botao foi apertado
     def esta_pressionado(self, botao ):
-        if( type(botao) != Botao ):
-            return False
-        else:
+        try:
             return botao.pressionado
+        except:
+            pass
 
     #espelha imagem
     #por padrão, espelha horizontalmente
@@ -586,6 +587,8 @@ class Botao():
         self.visivel = True
         lista_de_botoes.append(self)
 
+    #<bool>
+    #Mostra se o botão está sendo pressionado.
     @property
     def pressionado(self):
         if( self.rect.collidepoint(pygame.mouse.get_pos()) and
@@ -650,21 +653,21 @@ def verificar_eventos():
     global rodar_threading, tela
     tela._tela = pygame.display.set_mode( [tela.largura, tela.altura] ) 
     while rodar_threading:
-        pygame.time.Clock().tick( 400 )
+        pygame.time.Clock().tick( 200 )
 
-        if( tela.atualizar == True ):
+        if( tela.atualizar == True and not tela._tela.get_locked() ):
                     
             #preenche teala com cor de fundo
             tela._tela.fill(tela.cor )
             
             #exibe objetos
             for objeto in lista_de_objetos:
-                if( objeto.visivel ):
+                if( objeto.visivel and not objeto.imagem.get_locked() ):
                     tela._tela.blit( objeto.imagem, objeto.area_da_imagem )
 
             #exibe textos        
             for texto in lista_de_textos:
-                if( texto.visivel ):
+                if( texto.visivel and not texto.texto.get_locked() ):
                     tela._tela.blit(texto.texto, texto.posicao)
 
             #exibe botões
@@ -721,7 +724,7 @@ acoes_paralelas = []
 #Acao deve ser criada por uma funcao e após isso
 #a acao é adicionada usando esta função
 def adicionar_acao( acao, frequencia = 5000 ):
-    global acoes_paralelas
+    global acoes_paralelas, tela
     def acao_em_loop(): #tentar futuramente incluir numa lista
         while rodar_threading:
             pygame.time.Clock().tick( frequencia )
@@ -752,9 +755,4 @@ def pausar(tempo=False):
         
 #usado quando uma ação precisa de um intervalo entre uma
 #execução e outra
-esperar = time.sleep
-
-
-
-
-
+esperar = time.sleep
\ No newline at end of file
